==> espeak_1.16.orig.tar.gz: espeak-1.16/src/tr_languages.h <==
/***************************************************************************
 *   Copyright (C) 2005,2006 by Jonathan Duddington                        *
 *   jsd@clara.co.uk                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/




class Translator_English: public Translator
{//=======================================

public:
	Translator_English();
	int Unpronouncable(char *word);
};  // end of class Translator_English



class Translator_Russian: public Translator
{//=======================================

public:
	Translator_Russian();
private:
	int ChangePhonemes(PHONEME_LIST2 *phlist, int n_ph, int index, PHONEME_TAB *ph, int flags);

};  // end of class Translator_Russian





class Translator_Afrikaans: public Translator
{//==========================================

public:
	Translator_Afrikaans();
private:
	int TranslateChar(char *ptr, int prev_in, int c, int next_in);

};  // end of class Translator_Afrikaans




class Translator_Tone: public Translator
{//==========================================

public:
	Translator_Tone();
private:
	void CalcPitches(int clause_tone);

};  // end of class Translator_Tone

==> espeak_1.36.orig.tar.gz: espeak-1.36/src/tr_languages.h <==
/***************************************************************************
 *   Copyright (C) 2005 to 2007 by Jonathan Duddington                     *
 *   email: jonsd@users.sourceforge.net                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write see:                           *
 *               <http://www.gnu.org/licenses/>.                           *
 ***************************************************************************/





class Translator_English: public Translator
{//=======================================

public:
	Translator_English();
	int Unpronouncable(char *word);
};  // end of class Translator_English



class Translator_Russian: public Translator
{//=======================================

public:
	Translator_Russian();
private:
	int ChangePhonemes(PHONEME_LIST2 *phlist, int n_ph, int index, PHONEME_TAB *ph, CHANGEPH *ch);

};  // end of class Translator_Russian





class Translator_Afrikaans: public Translator
{//==========================================

public:
	Translator_Afrikaans();
private:
	int TranslateChar(char *ptr, int prev_in, unsigned int c, unsigned int next_in, int *insert);

};  // end of class Translator_Afrikaans
